[jbpm-commits] JBoss JBPM SVN: r2314 - in projects/jbpm-spec/trunk/modules/api: src/main/java/org/jboss/bpm/test and 1 other directory.

do-not-reply at jboss.org do-not-reply at jboss.org
Tue Sep 23 12:21:55 EDT 2008


Author: thomas.diesler at jboss.com
Date: 2008-09-23 12:21:54 -0400 (Tue, 23 Sep 2008)
New Revision: 2314

Modified:
   projects/jbpm-spec/trunk/modules/api/pom.xml
   projects/jbpm-spec/trunk/modules/api/src/main/java/org/jboss/bpm/test/IntegrationTestCase.java
Log:
Add access to MBeanServer

Modified: projects/jbpm-spec/trunk/modules/api/pom.xml
===================================================================
--- projects/jbpm-spec/trunk/modules/api/pom.xml	2008-09-23 13:10:34 UTC (rev 2313)
+++ projects/jbpm-spec/trunk/modules/api/pom.xml	2008-09-23 16:21:54 UTC (rev 2314)
@@ -27,24 +27,21 @@
 
   <!-- Dependencies -->
   <dependencies>
-
     <!-- Compile Dependencies -->
     <dependency>
-      <groupId>org.jboss.microcontainer</groupId>
-      <artifactId>jboss-kernel</artifactId>
-    </dependency>
-    <dependency>
       <groupId>commons-logging</groupId>
       <artifactId>commons-logging</artifactId>
     </dependency>
-    
+    <dependency>
+      <groupId>org.jboss.microcontainer</groupId>
+      <artifactId>jboss-kernel</artifactId>
+    </dependency>
     <!-- Provided Dependencies -->
     <dependency>
       <groupId>junit</groupId>
       <artifactId>junit</artifactId>
       <scope>provided</scope>
     </dependency>
-
   </dependencies>
   
   <!-- Plugins -->

Modified: projects/jbpm-spec/trunk/modules/api/src/main/java/org/jboss/bpm/test/IntegrationTestCase.java
===================================================================
--- projects/jbpm-spec/trunk/modules/api/src/main/java/org/jboss/bpm/test/IntegrationTestCase.java	2008-09-23 13:10:34 UTC (rev 2313)
+++ projects/jbpm-spec/trunk/modules/api/src/main/java/org/jboss/bpm/test/IntegrationTestCase.java	2008-09-23 16:21:54 UTC (rev 2314)
@@ -5,16 +5,16 @@
  * full listing of individual contributors.
  *
  * This is free software; you can redistribute it and/or modify it
- * under the terms of the GNU Lesser General Public License as
+ * under the terms of the GNU Lesser General protected License as
  * published by the Free Software Foundation; either version 2.1 of
  * the License, or (at your option) any later version.
  *
  * This software is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
- * Lesser General Public License for more details.
+ * Lesser General protected License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this software; if not, write to the Free
  * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
  * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
@@ -27,72 +27,61 @@
 import java.net.MalformedURLException;
 import java.net.URL;
 
+import javax.management.MBeanServerConnection;
+
 import junit.framework.TestCase;
 
 public abstract class IntegrationTestCase extends TestCase
 {
   private IntegrationTestHelper delegate = new IntegrationTestHelper();
 
-  /**
-   * Deploy the given archive
-   */
-  public void deploy(String archive) throws Exception
+  protected void deploy(String archive) throws Exception
   {
     delegate.deploy(archive);
   }
 
-  /**
-   * Undeploy the given archive
-   */
-  public void undeploy(String archive) throws Exception
+  protected void undeploy(String archive) throws Exception
   {
     delegate.undeploy(archive);
   }
 
-  public boolean isTargetJBoss500()
+  protected boolean isTargetJBoss500()
   {
     return delegate.isTargetJBoss500();
   }
 
-  public boolean isTargetJBoss423()
+  protected boolean isTargetJBoss423()
   {
     return delegate.isTargetJBoss423();
   }
 
-  public boolean isTargetJBoss422()
+  protected boolean isTargetJBoss422()
   {
     return delegate.isTargetJBoss422();
   }
 
-  /** 
-   * Discover the URL for the deployment archive 
-   */
-  public URL getArchiveURL(String archive) throws MalformedURLException
+  protected URL getArchiveURL(String archive) throws MalformedURLException
   {
     return delegate.getArchiveURL(archive);
   }
 
-  /** 
-   * Discover the File for the deployment archive 
-   */
-  public File getArchiveFile(String archive)
+  protected File getArchiveFile(String archive)
   {
     return delegate.getArchiveFile(archive);
   }
 
-  /** 
-   * Discover the URL for the test resource 
-   */
-  public URL getResourceURL(String resource) throws MalformedURLException
+  protected URL getResourceURL(String resource) throws MalformedURLException
   {
     return delegate.getResourceURL(resource);
   }
 
-  /** 
-   * Discover the File for the test resource 
-   */
-  public File getResourceFile(String resource)
+  protected File getResourceFile(String resource)
   {
     return delegate.getResourceFile(resource);
   }
+  
+  protected MBeanServerConnection getServer()
+  {
+    return IntegrationTestHelper.getServer();
+  }
 }
@@ -5,16 +5,16 @@
  *
- * You should have received a copy of the GNU Lesser General Public
+ * You should have received a copy of the GNU Lesser General protected
  * License along with this software; if not, write to the Free
  * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA




More information about the jbpm-commits mailing list